#ifndef DHSH
#define DHSH

/******************************************************************************
               DHS Constants
*******************************************************************************/
#if defined (_WIN32)
   #if !defined(WIN32)
     #define WIN32
   #endif
#endif

// flags
#define DHFLAG_RETURN_MSG_ID 0x1
#define DHFLAG_SEGMENT_ONLY  0x2
#define DHFLAG_EMBED_PICTURE 0x4
#define DHFLAG_NO_PICT_PATH  0x8
#define DHFLAG_LIST_TO_TEXT  0x10
#define DHFLAG_NO_LINK_IN_DOCX 0x20     // ignore links when converting from html to rtf
#define DHFLAG_WORDPAD_COMPATIBLE_PICT 0x40     // create WordPad compatible pictures in the rtf output
#define DHFLAG_NO_SPAN_TAG    0x80     // do not write the span tags
#define DHFLAG_NO_FONT        0x100    // do not write the font tag
#define DHFLAG_FLASH_SUPPORT  0x200    // html output for flash support
#define DHFLAG_XLATE_SINGLE_QUOTE 0x400  // translate single quote to &#39;
#define DHFLAG_SAVE_PICT_AS_BMP   0x800  // save picture as bmp in html output
#define DHFLAG_PNG_RGB           0x1000  // save png in rgb (high quality)
#define DHFLAG_FIX_NEG_INDENT    0x2000  // fix negative indent during docx read
#define DHFLAG_EMBED_HTML_PICTURE 0x4000  // embed pictures into html

#define HF_FIRST_HDR         0
#define HF_FIRST_FTR         1
#define HF_HDR               2
#define HF_FTR               3

#define HFTYPE_TEXT          0
#define HFTYPE_DOCX           1
#define HFTYPE_HTML          2

// Error messages
#define MSG_FILE_NOT_FOUND     1
#define MSG_NO_EDITOR_INSTANCE 2
#define MSG_READ_ERROR         3
#define MSG_WRITE_ERROR        4
#define MSG_MEMORY_LOCK        5
#define MSG_NO_FILE_SIGNATURE  6
#define MSG_BAD_DOCX_FILE       7
#define MSG_BAD_HTML_FILE      8
#define MSG_EXPIRED            9
#define MSG_TXML_NOT_LOADED   10
#define MSG_LICENSE_EXCEEDED   15
#define MSG_BAD_LICENSE_NUMBER 16
#define MSG_BAD_LICENSE_KEY    17
#define MSG_INVALID_SERVER_LICENSE 18
#define MSG_LICENSE_EXPIRED        19

#define MSG_OTHER             99

/******************************************************************************
    WIN32 specific defines
*******************************************************************************/
#if defined (WIN32)
   #define DHS_HUGE
   #define _export
#else
   #define DHS_HUGE huge
#endif


/****************************************************************************
   Instructions for packing the following structure
*****************************************************************************/
#ifndef RC_INVOKED
   #pragma pack(1)
#endif

/****************************************************************************
   Instructions to resume the default structure packing.
*****************************************************************************/
#ifndef RC_INVOKED
   #pragma pack()
#endif


/******************************************************************************
                     Editor Function Prototype
   When calling DHS from a C program, leave the DHS_CPLUSPLUS symbol undefined.

   When calling DHS from a C++ program, define the DHS_CPLUSPLUS as following:

   #define DHS_CPLUSPLUS extern "C"
   #include "ter.h"
*******************************************************************************/
#ifndef DHS_CPLUSPLUS
   #if defined(__cplusplus)
      #define DHS_CPLUSPLUS extern "C"
   #else
      #define DHS_CPLUSPLUS
   #endif
#endif

DHS_CPLUSPLUS DWORD_PTR   WINAPI _export DhsNewSession();
DHS_CPLUSPLUS BOOL    WINAPI _export DhsEndSession(DWORD_PTR);
DHS_CPLUSPLUS BOOL    WINAPI _export DhsConvertFile(DWORD_PTR,LPBYTE,LPBYTE);
DHS_CPLUSPLUS HGLOBAL WINAPI _export DhsConvertBuffer(DWORD_PTR,LPBYTE,int,LPINT);
DHS_CPLUSPLUS BOOL    WINAPI _export DhsHandleToStr(LPBYTE,int,HANDLE);
DHS_CPLUSPLUS int     WINAPI _export DhsGetLastMessage(DWORD_PTR,LPBYTE,LPBYTE);
DHS_CPLUSPLUS BOOL    WINAPI _export DhsResetLastMessage(DWORD_PTR);
DHS_CPLUSPLUS DWORD   WINAPI _export DhsSetFlags(DWORD_PTR,BOOL,int);
DHS_CPLUSPLUS int     WINAPI _export DhsGetPictCount(DWORD_PTR);
DHS_CPLUSPLUS BOOL    WINAPI _export DhsGetPictName(DWORD_PTR,int,LPBYTE);
DHS_CPLUSPLUS BOOL    WINAPI _export DhsSetPaperSize(DWORD_PTR, int, int, int);
DHS_CPLUSPLUS BOOL    WINAPI _export DhsSetPaperOrient(DWORD_PTR, int);
DHS_CPLUSPLUS BOOL    WINAPI _export DhsSetPageMargin(DWORD_PTR, int, int, int, int);
DHS_CPLUSPLUS BOOL    WINAPI _export DhsSetDownloadDir(DWORD_PTR, LPBYTE);
DHS_CPLUSPLUS BOOL    WINAPI _export DhsSetPictPrefix(DWORD_PTR, LPBYTE);
DHS_CPLUSPLUS BOOL    WINAPI _export DhsSetPictFolder(DWORD_PTR, LPBYTE);
DHS_CPLUSPLUS BOOL    WINAPI _export DhsSetImageSrcFolder(DWORD_PTR, LPBYTE);
DHS_CPLUSPLUS int     WINAPI _export DhsSetLicenseInfo(LPBYTE, LPBYTE, LPBYTE);
DHS_CPLUSPLUS int     WINAPI _export DhsSetLicenseInfoU(LPWORD,LPWORD,LPWORD);
DHS_CPLUSPLUS BOOL    WINAPI _export DhsSetInServer(BOOL);
DHS_CPLUSPLUS int     WINAPI _export DhsGetLicenseStatus();


#endif
